Package: ecodist
Version: 2.1.3
Date: 2023-10-30
Title: Dissimilarity-Based Functions for Ecological Analysis
Authors@R: c(person("Sarah", "Goslee", role = c("aut", "cre"),
                     email = "Sarah.Goslee@usda.gov"),
              person("Dean", "Urban", role = "aut"))
Author: Sarah Goslee [aut, cre],
  Dean Urban [aut]
Maintainer: Sarah Goslee <Sarah.Goslee@usda.gov>
Depends: R (>= 3.0.0)
LazyData: true
Imports: stats, graphics, igraph
Suggests: knitr, testthat, markdown
VignetteBuilder: knitr
Description: Dissimilarity-based analysis functions including ordination and Mantel test functions, intended for use with spatial and community ecological data. The original package description is in Goslee and Urban (2007) <doi:10.18637/jss.v022.i07>, with further statistical detail in Goslee (2010) <doi:10.1007/s11258-009-9641-0>.
License: GPL (>= 2)
BugReports: https://github.com/phiala/ecodist/issues
NeedsCompilation: yes
Packaged: 2023-10-30 14:30:01 UTC; sarahg
Repository: CRAN
Date/Publication: 2023-10-30 15:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 15:04:25 UTC; unix
Archs: ecodist.so.dSYM
